@@ -1,7 +1,6 @@
 import string
 import pyautogui as pyautogui
-# import cv2 # locate image confidece support
-from script.utils.utils import resource_path
+import utils.utils as utils
 
 secs_between_keys = 0.1
 
@@ -17,7 +16,7 @@ class Ui_tools:
 
     @staticmethod
     def click_on(ref: str):
-        position = Ui_tools.getPosition(resource_path(ref))
+        position = Ui_tools.getPosition(utils.resource_path(ref))
         Ui_tools.click(position)
 
     @staticmethod
